@@ -29,7 +29,7 @@
 
 import json
 import re
-from typing import Optional, Any, AnyStr
+from typing import Optional, Any
 
 from .struct import Package, UnixSocket, InetSocket
 from .. import utils, resource, tools, config, get_logger, ToolExecError
@@ -75,27 +75,24 @@ class Adb(object):
     def exec(
             cls,
             *args: [Any],
-            input: AnyStr = None,
             timeout: float = None,
             ignore_errors: bool = False,
-            output_to_logger: bool = False
+            log_output: bool = False
     ) -> str:
         """
         执行命令
         :param args: 命令
-        :param input: 输入
         :param timeout: 超时时间
         :param ignore_errors: 忽略错误，报错不会抛异常
-        :param output_to_logger: 把输出打印到logger中
+        :param log_output: 把输出打印到logger中
         :return: 如果是不是守护进程，返回输出结果；如果是守护进程，则返回Popen对象
         """
         try:
             return tools["adb"].exec(
                 *args,
-                input=input,
                 timeout=timeout,
                 ignore_errors=ignore_errors,
-                output_to_logger=output_to_logger,
+                log_output=log_output,
             )
         except ToolExecError as e:
             raise AdbError(e)
@@ -142,14 +139,14 @@ class Device(object):
             return "x86"
         raise AdbError("unknown abi: %s" % result)
 
-    @property
+    @cached_property
     def uid(self) -> int:
         """
         获取shell的uid
         :return: uid
         """
         default = -1
-        out = self.shell("echo", "-n", "${USER_ID}")
+        out = self.shell("id", "-u")
         uid = utils.int(out, default=default)
         if uid != default:
             return uid
@@ -278,11 +275,12 @@ class Device(object):
 
         return Stoppable()
 
-    def redirect(self, address: str = None, port: int = 8080) -> utils.Stoppable:
+    def redirect(self, address: str = None, port: int = 8080, uid: int = None) -> utils.Stoppable:
         """
         将手机流量重定向到本地指定端口
         :param address: 本地监听地址，不填默认本机
         :param port: 本地监听端口
+        :param uid: 监听目标uid
         :return: 重定向对象
         """
 
@@ -300,14 +298,13 @@ class Device(object):
 
         # 配置iptables规则，首先清除之前的规则，然后再把流量转发到目标端口上
         self.sudo("iptables", "-t", "nat", "-F")
-        self.sudo(
-            "iptables", "-t", "nat", "-A", "OUTPUT", "-p", "tcp",
-            "-o", "lo", "-j", "RETURN"  # 忽略localhost
-        )
-        self.sudo(
-            "iptables", "-t", "nat", "-A", "OUTPUT", "-p", "tcp",
-            "-j", "DNAT", "--to-destination", destination
-        )
+
+        args = ["-A", "OUTPUT", "-p", "tcp"]  # 添加一条tcp协议的转发规则
+        args += ["!", "-o", "lo"]  # 过滤localhost
+        if uid is not None:
+            args += ["-m", "owner", "--uid-owner", uid]  # 指定要重定向流量的uid
+        args += ["-j", "DNAT", "--to-destination", destination]  # 转发到指定端口
+        self.sudo("iptables", "-t", "nat", *args)
 
         # noinspection PyMethodParameters
         class Stoppable(utils.Stoppable):
@@ -596,7 +593,6 @@ class Device(object):
         :param paths: 文件名
         :return: 路径
         """
-        ""
         return "/data/local/tmp/%s" % (
             "/".join([cls.get_safe_path(o) for o in paths])
         )
