@@ -19,7 +19,7 @@ from frida.core import Session, Script
 
 from .script import FridaUserScript, FridaEvalCode, FridaScriptFile
 from .server import FridaServer
-from .utils import Counter
+from ._utils import Counter
 from .. import utils, resource, get_logger, environ
 
 _logger = get_logger("frida.app")
@@ -75,6 +75,8 @@ class FridaSession(utils.get_derived_type(Session)):  # proxy for frida.core.Ses
 
 class FridaScript(utils.get_derived_type(Script)):  # proxy for frida.core.Script
 
+    __super__: Script
+
     def __init__(self, session: FridaSession, script: Script):
         super().__init__(script)
         self._session: FridaSession = session
@@ -86,6 +88,12 @@ class FridaScript(utils.get_derived_type(Script)):  # proxy for frida.core.Scrip
     def session(self) -> FridaSession:
         return self._session
 
+    @property
+    def exports_sync(self):
+        if hasattr(self.__super__, "exports_sync"):
+            return self.__super__.exports_sync
+        return self.__super__.exports
+
     def add_message_handler(self, handler: "FridaScriptHandler"):
         self.remove_message_handler()
         self._message_handler = lambda msg, data: handler.on_script_message(self, msg, data)
@@ -260,7 +268,6 @@ class FridaApplication(FridaScriptHandler):
             enable_spawn_gating: bool = False,
             enable_child_gating: bool = False,
             eternalize: str = False,
-            logger=_logger,
     ):
         self._device = device
 
@@ -369,11 +376,6 @@ class FridaApplication(FridaScriptHandler):
         with self._lock:
             return {pid: session for pid, session in self._sessions.items() if not session.is_detached}
 
-    @property
-    def scripts(self) -> Dict[int, FridaScript]:
-        with self._lock:
-            return {pid: session.script for pid, session in self._sessions.items() if not session.is_detached}
-
     def schedule(self, fn: Callable[[], any], delay: float = None):
         self._reactor.schedule(fn, delay)
 
@@ -432,7 +434,7 @@ class FridaApplication(FridaScriptHandler):
             else self._internal_script.source
 
         script_kwargs = {}
-        if utils.split_version(frida.__version__) < (14,):
+        if utils.parse_version(frida.__version__) < (14,):
             script_kwargs["runtime"] = "v8"
         script = FridaScript(session, session.create_script(source, **script_kwargs))
         script.add_message_handler(self)
@@ -440,7 +442,7 @@ class FridaApplication(FridaScriptHandler):
 
         try:
             script.load()
-            script.exports.load_scripts(self._load_script_files(), self._user_parameters)
+            script.exports_sync.load_scripts(self._load_script_files(), self._user_parameters)
         finally:
             if resume:
                 utils.ignore_error(self.device.resume, pid)
@@ -663,7 +665,7 @@ class FridaApplication(FridaScriptHandler):
         :param payload: 上述例子的{trace: "xxx"}
         :param data: 上述例子的null
         """
-        _logger.debug(f"{script} send, payload={payload}")
+        _logger.info(f"{script} send, payload={payload}")
 
     def on_session_attached(self, session: FridaSession):
         """
