@@ -120,13 +120,11 @@ class FridaEvalCode(FridaUserScript):
 
 class FridaShareScript(FridaUserScript):
 
-    def __init__(self, url: str, cached: bool = False, trusted: bool = False, load: bool = False):
+    def __init__(self, url: str, cached: bool = False, trusted: bool = False):
         super().__init__()
         self._url = url
         self._cached = cached
         self._trusted = trusted
-        if load:
-            self.load()
 
     @property
     def filename(self):
@@ -166,7 +164,7 @@ class FridaShareScript(FridaUserScript):
             if len(source_lines) > line_count:
                 source_summary += "... ..."
 
-            table = Table(title=f"Shared script", show_lines=True)
+            table = Table(show_lines=True)
             table.add_column("Property", justify="right", style="cyan", no_wrap=True)
             table.add_column("Content", style="magenta")
             table.add_row("Url", self._url)
