@@ -37,35 +37,38 @@ from typing import Dict, Union, List, Tuple
 from urllib import parse
 
 from filelock import FileLock
-from rich.progress import BarColumn, DownloadColumn, Progress, \
-    TaskProgressColumn, TimeRemainingColumn, TransferSpeedColumn, TextColumn
 
-from ._utils import Timeout, get_md5, ignore_error, split_version
+from ._utils import Timeout, get_md5, ignore_error, parse_version
 from .._environ import resource, config, tools
-from .._logging import get_logger, LogColumn
-from ..decorator import cached_property
+from .._logging import get_logger, create_log_progress
+from ..decorator import cached_property, singleton
+from ..references.fake_useragent import UserAgent, VERSION as FAKE_USERAGENT_VERSION
 
 _logger = get_logger("utils.url")
-_user_agent = None
 
 DataType = Union[str, int, float]
 QueryType = Union[DataType, List[DataType], Tuple[DataType]]
 
 
+@singleton
+class _UserAgent(UserAgent):
+
+    def __init__(self):
+        super().__init__(
+            path=resource.get_asset_path(f"fake_useragent_{FAKE_USERAGENT_VERSION}.json")
+        )
+
+
 def user_agent(style=None) -> str:
     try:
-        from ..references.fake_useragent import UserAgent, VERSION
 
-        global _user_agent
-        if (not _user_agent) and style:
-            _user_agent = UserAgent(
-                path=resource.get_asset_path(f"fake_useragent_{VERSION}.json")
-            )
+        user_agent = _UserAgent()
 
         if style:
-            return _user_agent[style]
+            print(user_agent[style])
+            return user_agent[style]
 
-        return _user_agent.random
+        return user_agent.random
 
     except Exception as e:
         _logger.debug(f"fetch user agent error: {e}")
@@ -154,24 +157,13 @@ class DownloadContext:
             "Range": f"bytes={initial}-",
         }
 
-        progress = Progress(
-            LogColumn(),
-            TextColumn("[progress.description]{task.description}"),
-            BarColumn(),
-            DownloadColumn(),
-            TransferSpeedColumn(),
-            TaskProgressColumn(),
-            TextColumn("eta"),
-            TimeRemainingColumn(),
-        )
-
         try:
             import requests
             fn = self._download_with_requests
         except ModuleNotFoundError:
             fn = self._download_with_urllib
 
-        with progress:
+        with create_log_progress() as progress:
             task_id = progress.add_task(self.file_name, total=0)
             progress.advance(task_id, initial)
 
@@ -359,7 +351,7 @@ def get_chrome_driver(version: str):
     chrome_driver = tools["chromedriver80"]
     base_url = chrome_driver.config.get("base_url")
 
-    versions = split_version(version)
+    versions = parse_version(version)
     if versions[0] >= 70:
         file = UrlFile(f"{base_url}/LATEST_RELEASE_{versions[0]}")
         with open(file.save(), "rt") as fd:
@@ -370,7 +362,7 @@ def get_chrome_driver(version: str):
         version_map = json.load(fd)
 
     for key, value in version_map.items():
-        if versions[0] == split_version(value)[0]:
+        if versions[0] == parse_version(value)[0]:
             return chrome_driver.copy(version=key)
 
     raise NotFoundError(version)
