@@ -29,6 +29,7 @@
 import gzip
 import hashlib
 import random
+import re
 import socket
 import threading
 import time
@@ -68,6 +69,13 @@ class Timeout:
                 return False
         return True
 
+    def ensure(self) -> None:
+        if not self.check():
+            raise TimeoutError()
+
+    def __repr__(self):
+        return f"Timeout(timeout={self._timeout})"
+
 
 class InterruptableEvent(threading.Event):
     """
@@ -334,8 +342,17 @@ def get_wan_ip() -> Optional[str]:
         return None
 
 
-def split_version(version: str) -> [int, ...]:
-    return tuple(int(i, 0) for i in version.split("."))
+def parse_version(version: str) -> [int, ...]:
+    result = []
+    for x in version.split("."):
+        if x.isdigit():
+            result.append(int(x))
+        else:
+            match = re.match(r"^\d+", x)
+            if not match:
+                break
+            result.append(int(match.group(0)))
+    return tuple(result)
 
 
 def range_type(min: int, max: int):
