@@ -27,8 +27,19 @@
  /_==__==========__==_ooo__ooo=_/'   /___________,"
 """
 
+__version__ = "0.7.9"
+if not __version__[:1].isdigit():
+    __version__ = "0.0.1-debug"
+
 __name__ = "linktools"
-__version__ = "0.7.2"
 __author__ = "Hu Ji"
 __email__ = "669898595@qq.com"
 __url__ = "https://github.com/ice-black-tea/Zelda/tree/master"
+__summary__ = f"{__name__} toolkit"
+__description__ = f"""\
+    ___       __   __              __    
+   / (_)___  / /__/ /_____  ____  / /____
+  / / / __ \\/ //_/ __/ __ \\/ __ \\/ / ___/  {__summary__}
+ / / / / / / ,< / /_/ /_/ / /_/ / (__  )     by: @{__author__} 
+/_/_/_/ /_/_/|_|\\__/\\____/\\____/_/____/  
+"""
